@@ -31,8 +31,6 @@ my %dispatch = (
 $dispatch{$_}->() for @filter_names;
 
 my $channel  = CHANNEL;
-my $filters  = {};
-my $stash    = {};
 my $delay    = 0.1; # seconds
 my $feedback = 1;
 
@@ -64,11 +62,7 @@ $rtc->loop->add($tka);
 $rtc->run;
 
 sub add_filters ($coderef) {
-    add_filter($_ => $coderef) for qw(note_on note_off);
-}
-
-sub add_filter ($event_type, $action) {
-    push $rtc->_filters->{$event_type}->@*, $action;
+    $rtc->add_filter($_ => $coderef) for qw(note_on note_off);
 }
 
 sub pedal_notes ($note) {
