@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -43,6 +43,12 @@ has loop => (
     default => sub { IO::Async::Loop->new },
 );
 
+
+has filters => (
+    is      => 'rw',
+    default => sub { {} },
+);
+
 # Private attributes
 
 has _msg_channel => (
@@ -60,11 +66,6 @@ has _midi_out => (
     default => sub { RtMidiOut->new },
 );
 
-has _filters => (
-    is      => 'rw',
-    default => sub { {} },
-);
-
 
 sub BUILD {
     my ($self) = @_;
@@ -95,8 +96,8 @@ sub _log {
 
 sub _open_port($device, $name) {
     _log("Opening $device->{type} port $name ...");
-    $device->open_port_by_name(qr/\Q$name/i) ||
-            croak "Failed to open port $name";
+    $device->open_port_by_name(qr/\Q$name/i)
+        || croak "Failed to open port $name";
     _log("Opened $device->{type} port $name");
 }
 
@@ -108,7 +109,7 @@ sub _rtmidi_loop ($msg_ch, $midi_ch) {
 }
 
 sub _filter_and_forward ($self, $event) {
-    my $event_filters = $self->_filters->{ $event->[0] } // [];
+    my $event_filters = $self->filters->{ $event->[0] } // [];
     for my $filter ($event_filters->@*) {
         return if $filter->($event);
     }
@@ -135,6 +136,11 @@ sub run ($self) {
     $self->loop->run;
 }
 
+
+sub add_filter ($self, $event_type, $action) {
+    push $self->filters->{$event_type}->@*, $action;
+}
+
 1;
 
 __END__
@@ -149,7 +155,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0102
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -195,6 +201,12 @@ Return the MIDI B<output> port.
 
 Return the L<IO::Async::Loop>.
 
+=head2 filters
+
+  $filters = $rtc->filters;
+
+Return or set the B<filters>.
+
 =head1 METHODS
 
 =head2 new
@@ -223,6 +235,13 @@ Send a MIDI B<event> to the output port when the B<delay_time> expires.
 
 Run the B<loop>!
 
+=head2 add_filter
+
+  $rtc->add_filter($event_type, $action);
+
+Add a filter, defined by the CODE reference B<action>, for an
+B<event_type> like C<note_on> or B<note_off>.
+
 =head1 SEE ALSO
 
 The F<eg/*.pl> program(s)
